package com.ruoyi.web.controller.tg;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.domain.CustomerDeptPostRel;
import com.ruoyi.web.model.dto.CustomerDeptPostRelDto;
import com.ruoyi.web.service.ICustomerDeptPostRelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 客户-部门-岗位关联Controller
 *
 * @author ruoyi
 * @date 2025-04-08
 */
@Api(tags = "客户-部门-岗位关联管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/customer/dept/post/rel")
public class CustomerDeptPostRelController extends BaseController {
    private final ICustomerDeptPostRelService customerDeptPostRelService;

    /**
     * 查询客户-部门-岗位关联列表
     */
    @ApiOperation("查询客户-部门-岗位关联列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页大小", dataType = "int", paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('web:rel:list')")
    @GetMapping("/list")
    public TableDataInfo list(CustomerDeptPostRel customerDeptPostRel) {
        startPage();
        List<CustomerDeptPostRelDto> list = customerDeptPostRelService.selectCustomerDeptPostRelList(customerDeptPostRel);

        return getDataTable(list);
    }

    /**
     * 获取客户-部门-岗位关联详细信息
     */
    @ApiOperation("获取客户-部门-岗位关联详细信息")
    @ApiImplicitParam(name = "id", value = "主键ID", required = true, dataType = "Long")
    @PreAuthorize("@ss.hasPermi('web:rel:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable Long id) {
        return AjaxResult.success(customerDeptPostRelService.selectCustomerDeptPostRelById(id));
    }

    /**
     * 新增客户-部门-岗位关联
     */
    @ApiOperation("新增客户-部门-岗位关联")
    @PreAuthorize("@ss.hasPermi('web:rel:add')")
    @Log(title = "客户-部门-岗位关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CustomerDeptPostRel customerDeptPostRel) {
        return toAjax(customerDeptPostRelService.insertCustomerDeptPostRel(customerDeptPostRel));
    }

    /**
     * 修改客户-部门-岗位关联
     */
    @ApiOperation("修改客户-部门-岗位关联")
    @PreAuthorize("@ss.hasPermi('web:rel:edit')")
    @Log(title = "客户-部门-岗位关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CustomerDeptPostRel customerDeptPostRel) {
        return toAjax(customerDeptPostRelService.updateCustomerDeptPostRel(customerDeptPostRel));
    }

    /**
     * 删除客户-部门-岗位关联
     */
    @ApiOperation("删除客户-部门-岗位关联")
    @PreAuthorize("@ss.hasPermi('web:rel:remove')")
    @Log(title = "客户-部门-岗位关联", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(customerDeptPostRelService.deleteCustomerDeptPostRelByIds(ids));
    }
}