package com.ruoyi.web.controller.tg;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.web.domain.DeviceInfo;
import com.ruoyi.web.model.dto.CreateDeviceInfoDto;
import com.ruoyi.web.model.dto.DeviceListDto;
import com.ruoyi.web.service.IDeviceInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 设备信息Controller
 *
 * @author cx
 * @date 2025-04-05
 */
@Api(tags = "设备信息管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/device/info")
public class DeviceInfoController extends BaseController {
    private final IDeviceInfoService deviceInfoService;

    /**
     * 查询设备信息列表
     */
    @ApiOperation("查询设备信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页大小", dataType = "int", paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('web:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(DeviceInfo deviceInfo) {
        startPage();
        List<DeviceListDto> list = deviceInfoService.selectDeviceInfoList(deviceInfo);
        return getDataTable(list);
    }

    /**
     * 导出设备信息列表
     */
    @ApiOperation("导出设备信息列表")
    @PreAuthorize("@ss.hasPermi('web:info:export')")
    @Log(title = "设备信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(DeviceInfo deviceInfo) {
        List<DeviceListDto> list = deviceInfoService.selectDeviceInfoList(deviceInfo);
        ExcelUtil<DeviceListDto> util = new ExcelUtil<DeviceListDto>(DeviceListDto.class);
        return util.exportExcel(list, "设备信息数据");
    }

    /**
     * 获取设备信息详细信息
     */
    @ApiOperation("获取设备信息详细信息")
    @ApiImplicitParam(name = "id", value = "主键ID", required = true, dataType = "String")
    @PreAuthorize("@ss.hasPermi('web:info:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable String id) {
        return AjaxResult.success(deviceInfoService.selectDeviceInfoById(id));
    }

    /**
     * 新增设备信息
     */
    @ApiOperation("新增设备信息")
    @PreAuthorize("@ss.hasPermi('web:info:add')")
    @Log(title = "设备信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody CreateDeviceInfoDto deviceInfo) {
        return toAjax(deviceInfoService.createDeviceInfo(deviceInfo));
    }

    /**
     * 修改设备信息
     */
    @ApiOperation("修改设备信息")
    @PreAuthorize("@ss.hasPermi('web:info:edit')")
    @Log(title = "设备信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DeviceInfo deviceInfo) {
        return toAjax(deviceInfoService.updateDeviceInfo(deviceInfo));
    }

    /**
     * 删除设备信息
     */
    @ApiOperation("删除设备信息")
    @PreAuthorize("@ss.hasPermi('web:info:remove')")
    @Log(title = "设备信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(deviceInfoService.deleteDeviceInfoByIds(ids));
    }
}