package com.ruoyi.web.controller.tg;
import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.domain.DeviceModel;
import com.ruoyi.web.service.IDeviceModelService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;

/**
 * 设备型号Controller
 *
 * @author cx
 * @date 2025-04-05
 */
@Api(tags = "设备型号管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/device/model")
public class DeviceModelController extends BaseController
{
    private final IDeviceModelService deviceModelService;

    /**
     * 查询设备型号列表
     */
    @ApiOperation("查询设备型号列表")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "页码", dataType = "int", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页大小", dataType = "int", paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('web:model:list')")
    @GetMapping("/list")
    public TableDataInfo list(DeviceModel deviceModel)
    {
        startPage();
        List<DeviceModel> list = deviceModelService.selectDeviceModelList(deviceModel);
        return getDataTable(list);
    }

    /**
     * 导出设备型号列表
     */
    @ApiOperation("导出设备型号列表")
    @PreAuthorize("@ss.hasPermi('web:model:export')")
    @Log(title = "设备型号", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(DeviceModel deviceModel)
    {
        List<DeviceModel> list = deviceModelService.selectDeviceModelList(deviceModel);
        ExcelUtil<DeviceModel> util = new ExcelUtil<DeviceModel>(DeviceModel.class);
        return util.exportExcel(list, "设备型号数据");
    }

    /**
     * 获取设备型号详细信息
     */
    @ApiOperation("获取设备型号详细信息")
    @ApiImplicitParam(name = "id", value = "主键ID", required = true, dataType = "String")
    @PreAuthorize("@ss.hasPermi('web:model:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable String id)
    {
        return AjaxResult.success(deviceModelService.selectDeviceModelById(id));
    }

    /**
     * 新增设备型号
     */
    @ApiOperation("新增设备型号")
    @PreAuthorize("@ss.hasPermi('web:model:add')")
    @Log(title = "设备型号", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DeviceModel deviceModel)
    {
        return toAjax(deviceModelService.insertDeviceModel(deviceModel));
    }

    /**
     * 修改设备型号
     */
    @ApiOperation("修改设备型号")
    @PreAuthorize("@ss.hasPermi('web:model:edit')")
    @Log(title = "设备型号", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DeviceModel deviceModel)
    {
        return toAjax(deviceModelService.updateDeviceModel(deviceModel));
    }

    /**
     * 删除设备型号
     */
    @ApiOperation("删除设备型号")
    @PreAuthorize("@ss.hasPermi('web:model:remove')")
    @Log(title = "设备型号", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {

        throw new RuntimeException("额外一场");
//        return toAjax(deviceModelService.deleteDeviceModelByIds(ids));
    }
}