package com.ruoyi.web.controller.tg;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.web.domain.DeviceModel;
import org.apache.commons.compress.utils.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.domain.DeviceThreshold;
import com.ruoyi.web.service.IDeviceThresholdService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;

/**
 * 设备指标阈值信息Controller
 *
 * @author cx
 * @date 2025-04-05
 */
@Api(tags = "设备指标阈值信息管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/device/threshold")
public class DeviceThresholdController extends BaseController {
    private final IDeviceThresholdService deviceThresholdService;


    @PreAuthorize("@ss.hasPermi('web:threshold:list')")
    @GetMapping("/list")
    public TableDataInfo list(DeviceThreshold deviceThreshold)
    {
        startPage();
        List<DeviceThreshold> list = deviceThresholdService.selectDeviceThresholdList(deviceThreshold);
        return getDataTable(list);
    }

    /**
     * 获取设备指标阈值信息详细信息
     */
    @ApiOperation("获取设备指标阈值信息详细信息")
    @ApiImplicitParam(name = "deviceCode", value = "设备编码", required = true, dataType = "String")
    @PreAuthorize("@ss.hasPermi('web:threshold:query')")
    @GetMapping("/{deviceCode}")
    public AjaxResult getInfo(@PathVariable String deviceCode) {
        return AjaxResult.success(deviceThresholdService.selectDeviceThresholdById(deviceCode));
    }

    /**
     * 修改设备指标阈值信息
     */
    @ApiOperation("修改设备指标阈值信息")
    @PreAuthorize("@ss.hasPermi('web:threshold:edit')")
    @Log(title = "设备指标阈值信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DeviceThreshold deviceThreshold) {
        return toAjax(deviceThresholdService.updateDeviceThreshold(deviceThreshold));
    }

    /**
     * 批量复制设备指标阈值信息
     */
    @ApiOperation("批量复制设备指标阈值信息")
    @PreAuthorize("@ss.hasPermi('web:threshold:edit')")
    @Log(title = "批量复制设备指标阈值信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult batchInsert() {
        DeviceThreshold sourceData = deviceThresholdService.getById(1);
        ArrayList<DeviceThreshold> batchResult = Lists.newArrayList();
        for (int i = 50000; i < 50020; i++) {
            DeviceThreshold deviceThreshold = new DeviceThreshold();
            BeanUtils.copyProperties(sourceData, deviceThreshold);
            deviceThreshold.setDeviceCode(String.valueOf(i));
            deviceThreshold.setId(null);
            batchResult.add(deviceThreshold);
        }
        return toAjax(deviceThresholdService.saveBatch(batchResult));
    }
}