package com.ruoyi.web.controller.tg;
import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.domain.DeviceUserRel;
import com.ruoyi.web.service.IDeviceUserRelService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;

/**
 * 设备用户关联信息Controller
 *
 * @author cx
 * @date 2025-04-05
 */
@Api(tags = "设备用户关联信息管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/device/user/rel")
public class DeviceUserRelController extends BaseController
{
    private final IDeviceUserRelService deviceUserRelService;

    /**
     * 查询设备用户关联信息列表
     */
    @ApiOperation("查询设备用户关联信息列表")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "页码", dataType = "int", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页大小", dataType = "int", paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('web:rel:list')")
    @GetMapping("/list")
    public TableDataInfo list(DeviceUserRel deviceUserRel)
    {
        startPage();
        List<DeviceUserRel> list = deviceUserRelService.selectDeviceUserRelList(deviceUserRel);
        return getDataTable(list);
    }

    /**
     * 导出设备用户关联信息列表
     */
    @ApiOperation("导出设备用户关联信息列表")
    @PreAuthorize("@ss.hasPermi('web:rel:export')")
    @Log(title = "设备用户关联信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(DeviceUserRel deviceUserRel)
    {
        List<DeviceUserRel> list = deviceUserRelService.selectDeviceUserRelList(deviceUserRel);
        ExcelUtil<DeviceUserRel> util = new ExcelUtil<DeviceUserRel>(DeviceUserRel.class);
        return util.exportExcel(list, "设备用户关联信息数据");
    }

    /**
     * 获取设备用户关联信息详细信息
     */
    @ApiOperation("获取设备用户关联信息详细信息")
    @ApiImplicitParam(name = "id", value = "主键ID", required = true, dataType = "String")
    @PreAuthorize("@ss.hasPermi('web:rel:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable String id)
    {
        return AjaxResult.success(deviceUserRelService.selectDeviceUserRelById(id));
    }

    /**
     * 新增设备用户关联信息
     */
    @ApiOperation("新增设备用户关联信息")
    @PreAuthorize("@ss.hasPermi('web:rel:add')")
    @Log(title = "设备用户关联信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DeviceUserRel deviceUserRel)
    {
        return toAjax(deviceUserRelService.insertDeviceUserRel(deviceUserRel));
    }

    /**
     * 修改设备用户关联信息
     */
    @ApiOperation("修改设备用户关联信息")
    @PreAuthorize("@ss.hasPermi('web:rel:edit')")
    @Log(title = "设备用户关联信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DeviceUserRel deviceUserRel)
    {
        return toAjax(deviceUserRelService.updateDeviceUserRel(deviceUserRel));
    }

    /**
     * 删除设备用户关联信息
     */
    @ApiOperation("删除设备用户关联信息")
    @PreAuthorize("@ss.hasPermi('web:rel:remove')")
    @Log(title = "设备用户关联信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(deviceUserRelService.deleteDeviceUserRelByIds(ids));
    }
}