package com.ruoyi.web.controller.tg;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.domain.EmqxAuth;
import com.ruoyi.web.service.IEmqxAuthService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 设备-EMQX鉴权信息Controller
 *
 * @author ruoyi
 * @date 2025-04-08
 */
@Api(tags = "设备-EMQX鉴权信息管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/emqx/auth")
public class EmqxAuthController extends BaseController {
    private final IEmqxAuthService emqxAuthService;

    /**
     * 查询设备-EMQX鉴权信息列表
     */
    @ApiOperation("查询设备-EMQX鉴权信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页大小", dataType = "int", paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('web:auth:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmqxAuth emqxAuth) {
        startPage();
        List<EmqxAuth> list = emqxAuthService.selectEmqxAuthList(emqxAuth);
        return getDataTable(list);
    }

    /**
     * 获取设备-EMQX鉴权信息详细信息
     */
    @ApiOperation("获取设备-EMQX鉴权信息详细信息")
    @ApiImplicitParam(name = "id", value = "主键ID", required = true, dataType = "String")
    @PreAuthorize("@ss.hasPermi('web:auth:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable String id) {
        return AjaxResult.success(emqxAuthService.selectEmqxAuthById(id));
    }

    /**
     * 新增设备-EMQX鉴权信息
     */
    @ApiOperation("新增设备-EMQX鉴权信息")
    @PreAuthorize("@ss.hasPermi('web:auth:add')")
    @Log(title = "设备-EMQX鉴权信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmqxAuth emqxAuth) {
        return toAjax(emqxAuthService.insertEmqxAuth(emqxAuth));
    }

    /**
     * 修改设备-EMQX鉴权信息
     */
    @ApiOperation("修改设备-EMQX鉴权信息")
    @PreAuthorize("@ss.hasPermi('web:auth:edit')")
    @Log(title = "设备-EMQX鉴权信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmqxAuth emqxAuth) {
        return toAjax(emqxAuthService.updateEmqxAuth(emqxAuth));
    }

    /**
     * 删除设备-EMQX鉴权信息
     */
    @ApiOperation("删除设备-EMQX鉴权信息")
    @PreAuthorize("@ss.hasPermi('web:auth:remove')")
    @Log(title = "设备-EMQX鉴权信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(emqxAuthService.deleteEmqxAuthByIds(ids));
    }
}