package com.ruoyi.web.controller.tg;

import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.domain.MaintenanceRecord;
import com.ruoyi.web.service.IMaintenanceRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;

/**
 * 设备维保记录Controller
 *
 * @author cx
 * @date 2025-04-05
 */
@Api(tags = "设备维保记录管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/maintain/record")
public class MaintenanceRecordController extends BaseController {
    private final IMaintenanceRecordService maintenanceRecordService;

    /**
     * 查询设备维保记录列表
     */
    @ApiOperation("查询设备维保记录列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页大小", dataType = "int", paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('web:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(MaintenanceRecord maintenanceRecord) {
        startPage();
        List<MaintenanceRecord> list = maintenanceRecordService.selectMaintenanceRecordList(maintenanceRecord);
        return getDataTable(list);
    }

    /**
     * 导出设备维保记录列表
     */
    @ApiOperation("导出设备维保记录列表")
    @PreAuthorize("@ss.hasPermi('web:record:export')")
    @Log(title = "设备维保记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MaintenanceRecord maintenanceRecord) {
        List<MaintenanceRecord> list = maintenanceRecordService.selectMaintenanceRecordList(maintenanceRecord);
        ExcelUtil<MaintenanceRecord> util = new ExcelUtil<MaintenanceRecord>(MaintenanceRecord.class);
        return util.exportExcel(list, "设备维保记录数据");
    }

    /**
     * 获取设备维保记录详细信息
     */
    @ApiOperation("获取设备维保记录详细信息")
    @ApiImplicitParam(name = "id", value = "主键ID", required = true, dataType = "String")
    @PreAuthorize("@ss.hasPermi('web:record:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable String id) {
        return AjaxResult.success(maintenanceRecordService.selectMaintenanceRecordById(id));
    }

    /**
     * 新增设备维保记录
     */
    @ApiOperation("新增设备维保记录")
    @PreAuthorize("@ss.hasPermi('web:record:add')")
    @Log(title = "设备维保记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MaintenanceRecord maintenanceRecord) {
        return toAjax(maintenanceRecordService.insertMaintenanceRecord(maintenanceRecord));
    }

    /**
     * 修改设备维保记录
     */
    @ApiOperation("修改设备维保记录")
    @PreAuthorize("@ss.hasPermi('web:record:edit')")
    @Log(title = "设备维保记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MaintenanceRecord maintenanceRecord) {
        return toAjax(maintenanceRecordService.updateMaintenanceRecord(maintenanceRecord));
    }

    /**
     * 删除设备维保记录
     */
    @ApiOperation("删除设备维保记录")
    @PreAuthorize("@ss.hasPermi('web:record:remove')")
    @Log(title = "设备维保记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(maintenanceRecordService.deleteMaintenanceRecordByIds(ids));
    }
}