package com.ruoyi.web.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.system.domain.SysPost;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.mapper.SysPostMapper;
import com.ruoyi.web.domain.CustomerDeptPostRel;
import com.ruoyi.web.mapper.CustomerDeptPostRelMapper;
import com.ruoyi.web.model.dto.CustomerDeptPostRelDto;
import com.ruoyi.web.service.ICustomerDeptPostRelService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * 客户-部门-岗位关联Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-08
 */
@Service
@RequiredArgsConstructor
public class CustomerDeptPostRelServiceImpl extends ServiceImpl<CustomerDeptPostRelMapper, CustomerDeptPostRel> implements ICustomerDeptPostRelService {
    private final CustomerDeptPostRelMapper customerDeptPostRelMapper;
    private final SysPostMapper sysPostMapper;
    private final SysDeptMapper sysDeptMapper;

    /**
     * 查询客户-部门-岗位关联
     *
     * @param id 客户-部门-岗位关联主键
     * @return 客户-部门-岗位关联
     */
    @Override
    public CustomerDeptPostRel selectCustomerDeptPostRelById(Long id) {
        return getById(id);
    }

    /**
     * 查询客户-部门-岗位关联列表
     *
     * @param customerDeptPostRel 客户-部门-岗位关联
     * @return 客户-部门-岗位关联
     */
    @Override
    public List<CustomerDeptPostRelDto> selectCustomerDeptPostRelList(CustomerDeptPostRel customerDeptPostRel) {
        LambdaQueryWrapper<CustomerDeptPostRel> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(customerDeptPostRel.getCustomerId() != null, CustomerDeptPostRel::getCustomerId, customerDeptPostRel.getCustomerId());
        wrapper.eq(customerDeptPostRel.getDeptId() != null, CustomerDeptPostRel::getDeptId, customerDeptPostRel.getDeptId());
        wrapper.eq(customerDeptPostRel.getPostId() != null, CustomerDeptPostRel::getPostId, customerDeptPostRel.getPostId());
        List<CustomerDeptPostRel> list = list(wrapper);
        return assembleName(list);
    }

    /**
     * 组装Name属性
     *
     * @param list
     * @return
     */
    private List<CustomerDeptPostRelDto> assembleName(List<CustomerDeptPostRel> list) {
        if (CollectionUtils.isEmpty(list)) {
            return Collections.emptyList();
        }
        List<Long> deptIdList = list.stream()
                .flatMap(rel -> Stream.of(rel.getCustomerId(), rel.getDeptId()))
                .toList();
        List<SysDept> deptList = sysDeptMapper.selectBatchIds(deptIdList);
        Map<Long, SysDept> deptMap = deptList.stream().collect(Collectors.toMap(SysDept::getDeptId, Function.identity()));
        List<Long> postIdList = list.stream().map(CustomerDeptPostRel::getPostId).toList();
        List<SysPost> sysPosts = sysPostMapper.selectBatchIds(postIdList);
        Map<Long, SysPost> postMap = sysPosts.stream().collect(Collectors.toMap(SysPost::getPostId, Function.identity()));

        return list.stream().map(item -> {
            CustomerDeptPostRelDto dto = new CustomerDeptPostRelDto();
            BeanUtils.copyProperties(item, dto);
            dto.setCustomerName(deptMap.get(item.getCustomerId()).getDeptName());
            dto.setDeptName(deptMap.get(item.getDeptId()).getDeptName());
            dto.setPostName(postMap.get(item.getPostId()).getPostName());
            dto.setCreateBy(postMap.get(item.getPostId()).getCreateBy());
            dto.setCreateTime(postMap.get(item.getPostId()).getCreateTime());
            return dto;
        }).toList();
    }

    /**
     * 新增客户-部门-岗位关联
     *
     * @param customerDeptPostRel 客户-部门-岗位关联
     * @return 结果
     */
    @Override
    public int insertCustomerDeptPostRel(CustomerDeptPostRel customerDeptPostRel) {
        return save(customerDeptPostRel) ? 1 : 0;
    }

    /**
     * 修改客户-部门-岗位关联
     *
     * @param customerDeptPostRel 客户-部门-岗位关联
     * @return 结果
     */
    @Override
    public int updateCustomerDeptPostRel(CustomerDeptPostRel customerDeptPostRel) {
        return updateById(customerDeptPostRel) ? 1 : 0;
    }

    /**
     * 批量删除客户-部门-岗位关联
     *
     * @param ids 需要删除的客户-部门-岗位关联主键
     * @return 结果
     */
    @Override
    public int deleteCustomerDeptPostRelByIds(Long[] ids) {
        return removeByIds(Arrays.asList(ids)) ? 1 : 0;
    }

    /**
     * 删除客户-部门-岗位关联信息
     *
     * @param id 客户-部门-岗位关联主键
     * @return 结果
     */
    @Override
    public int deleteCustomerDeptPostRelById(Long id) {
        return removeById(id) ? 1 : 0;
    }
}