package com.ruoyi.web.service.impl;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.system.service.ISysPostService;
import com.ruoyi.web.domain.CustomerDeptPostRel;
import com.ruoyi.web.model.dto.CreateCustomerDto;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 客户用户关联信息Service业务层处理
 *
 * @author cx
 * @date 2025-04-05
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class CustomerUserRelServiceImpl {

    private final ISysDeptService sysDeptService;

    private final ISysPostService sysPostService;
    private final CustomerDeptPostRelServiceImpl customerDeptPostRelServiceImpl;

    public void addCustomer(CreateCustomerDto createCustomerDto) {
        //天宫制造公司目录下进行创建对应的部门
        SysDept sysDept = assembleSysDept(createCustomerDto);
        sysDeptService.insertDept(sysDept);
        log.info("SysDept insert success,and Return Id : {}", sysDept.getDeptId());
        List<SysDept> deptList = initDefaultDept(sysDept);

        initDefaultPost(sysDept, deptList);
    }

    /**
     * 每个部门，默认创建两个岗位
     *
     * @param sysDept
     * @param deptList
     */
    private void initDefaultPost(SysDept sysDept, List<SysDept> deptList) {
        Long customerId = sysDept.getDeptId();
        ArrayList<CustomerDeptPostRel> customerDeptPostRels = new ArrayList<>();
        deptList.forEach(dept -> {
            CustomerDeptPostRel customerDeptPostRel1 = CustomerDeptPostRel.builder()
                    .customerId(customerId)
                    .deptId(dept.getDeptId())
                    .postId(5L)
                    .build();
            CustomerDeptPostRel customerDeptPostRel2 = CustomerDeptPostRel.builder()
                    .customerId(customerId)
                    .deptId(dept.getDeptId())
                    .postId(6L)
                    .build();
            customerDeptPostRels.add(customerDeptPostRel1);
            customerDeptPostRels.add(customerDeptPostRel2);
        });
        customerDeptPostRelServiceImpl.saveBatch(customerDeptPostRels);
    }

    /**
     * 初始化默认部门
     * @param sysDept
     * @return
     */
    private List<SysDept> initDefaultDept(SysDept sysDept) {
        ArrayList<SysDept> deptList = new ArrayList<>();
        SysDept dept1 = new SysDept();
        dept1.setCreateBy(sysDept.getCreateBy());
        dept1.setDeptName("运维部");
        dept1.setParentId(sysDept.getDeptId());
        dept1.setAncestors(sysDept.getAncestors() + "," + sysDept.getDeptId());
        dept1.setCreateTime(new Date());
        deptList.add(dept1);
        SysDept dept2 = new SysDept();
        dept2.setCreateBy(sysDept.getCreateBy());
        dept2.setDeptName("研发部");
        dept2.setParentId(sysDept.getDeptId());
        dept2.setAncestors(sysDept.getAncestors() + "," + sysDept.getDeptId());
        dept2.setCreateTime(new Date());
        deptList.add(dept2);
        sysDeptService.saveBatch(deptList);
        return deptList;
    }

    /**
     * 组装部门信息
     *
     * @param createCustomerDto
     * @return
     */
    private SysDept assembleSysDept(CreateCustomerDto createCustomerDto) {
        SysDept sysDept = new SysDept();
        sysDept.setDeptName(createCustomerDto.getCustomerName());
        sysDept.setAddress(createCustomerDto.getAddress());
        sysDept.setPhone(createCustomerDto.getPhone());
        sysDept.setLeader(createCustomerDto.getLeader());
        sysDept.setCreateBy(SecurityUtils.getUsername());
        //default setting
        sysDept.setParentId(100L);
        sysDept.setAncestors("0,100");
        return sysDept;
    }
}