package com.ruoyi.web.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.web.domain.DeviceInfo;
import com.ruoyi.web.domain.DeviceUserRel;
import com.ruoyi.web.domain.EmqxAuth;
import com.ruoyi.web.mapper.DeviceInfoMapper;
import com.ruoyi.web.mapper.DeviceModelMapper;
import com.ruoyi.web.model.dto.CreateDeviceInfoDto;
import com.ruoyi.web.model.dto.DeviceListDto;
import com.ruoyi.web.model.dto.DeviceUserRelDto;
import com.ruoyi.web.model.index.OverViewDto;
import com.ruoyi.web.service.IDeviceInfoService;
import com.ruoyi.web.service.IDeviceThresholdService;
import com.ruoyi.web.service.IDeviceUserRelService;
import com.ruoyi.web.service.IEmqxAuthService;
import lombok.RequiredArgsConstructor;
import org.springframework.aop.framework.AopContext;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.beans.Transient;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 设备信息Service业务层处理
 *
 * @author cx
 * @date 2025-04-05
 */
@Service
@RequiredArgsConstructor
public class DeviceInfoServiceImpl extends ServiceImpl<DeviceInfoMapper, DeviceInfo> implements IDeviceInfoService {
    private final IDeviceUserRelService deviceUserRelService;
    private final IEmqxAuthService emqxAuthService;
    private final IDeviceThresholdService deviceThresholdService;
    private final SysUserMapper sysUserMapper;
    private final DeviceModelMapper deviceModelMapper;

    /**
     * 查询设备信息
     *
     * @param id 设备信息主键
     * @return 设备信息
     */
    @Override
    public DeviceInfo selectDeviceInfoById(String id) {
        return getById(id);
    }

    /**
     * 查询设备信息列表
     *
     * @param deviceInfo 设备信息
     * @return 设备信息
     */
    @Override
    public List<DeviceListDto> selectDeviceInfoList(DeviceInfo deviceInfo) {
        LambdaQueryWrapper<DeviceInfo> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(deviceInfo.getDeviceName() != null, DeviceInfo::getDeviceName, deviceInfo.getDeviceName());
        wrapper.eq(deviceInfo.getDeviceModel() != null, DeviceInfo::getDeviceModel, deviceInfo.getDeviceModel());
        wrapper.eq(deviceInfo.getDeviceCode() != null, DeviceInfo::getDeviceCode, deviceInfo.getDeviceCode());
        wrapper.eq(deviceInfo.getCustomerId() != null, DeviceInfo::getCustomerId, deviceInfo.getCustomerId());
        wrapper.eq(deviceInfo.getLifespan() != null, DeviceInfo::getLifespan, deviceInfo.getLifespan());
        wrapper.eq(deviceInfo.getUsedTime() != null, DeviceInfo::getUsedTime, deviceInfo.getUsedTime());
        wrapper.eq(deviceInfo.getDeviceStatus() != null, DeviceInfo::getDeviceStatus, deviceInfo.getDeviceStatus());
        wrapper.eq(deviceInfo.getServiceStatus() != null, DeviceInfo::getServiceStatus, deviceInfo.getServiceStatus());
        List<DeviceInfo> deviceInfoList = list(wrapper);
        if (CollectionUtils.isEmpty(deviceInfoList)) {
            return Collections.emptyList();
        }
        List<String> deviceCodeList = deviceInfoList.stream().map(DeviceInfo::getDeviceCode).toList();
        LambdaQueryWrapper<DeviceUserRel> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(DeviceUserRel::getDeviceCode, deviceCodeList);
        List<DeviceUserRel> deviceUserRelList = deviceUserRelService.list(queryWrapper);
        List<SysUser> sysUsers = sysUserMapper.selectUserListBatchById();
        Map<Long, SysUser> userMap = sysUsers.stream().collect(Collectors.toMap(SysUser::getUserId, Function.identity()));
        Map<String, List<DeviceUserRelDto>> deviceUserMap = deviceUserRelList.stream().map(rel-> {
                    DeviceUserRelDto deviceUserRelDto = new DeviceUserRelDto();
                    deviceUserRelDto.setDeviceCode(rel.getDeviceCode());
                    deviceUserRelDto.setUserId(rel.getUserId());
                    deviceUserRelDto.setUserName(userMap.get(rel.getUserId()).getUserName());
                    deviceUserRelDto.setDeptName(userMap.get(rel.getUserId()).getDeptName());
                    deviceUserRelDto.setStatus(userMap.get(rel.getUserId()).getStatus());
                    deviceUserRelDto.setPhone(userMap.get(rel.getUserId()).getPhonenumber());
                    return deviceUserRelDto;
                }).collect(Collectors.groupingBy(DeviceUserRel::getDeviceCode));
        return deviceInfoList.stream().map(info -> {
            DeviceListDto deviceListDto = new DeviceListDto();
            BeanUtils.copyProperties(info, deviceListDto);
            deviceListDto.setUserRelList(deviceUserMap.get(deviceListDto.getDeviceCode()));
            return deviceListDto;
        }).toList();
    }

    /**
     * 新增设备信息
     *
     * @param deviceInfo 设备信息
     * @return 结果
     */
    @Override
    public int insertDeviceInfo(DeviceInfo deviceInfo) {
        return save(deviceInfo) ? 1 : 0;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int createDeviceInfo(CreateDeviceInfoDto dto) {
        validModelCode(dto);
        //step1 组装设备信息，保存
        DeviceInfo deviceInfo = new DeviceInfo();
        BeanUtils.copyProperties(dto, deviceInfo);
        deviceInfo.setCreateBy(SecurityUtils.getUsername());
        deviceInfo.setCreateTime(new Date());
        ((DeviceInfoServiceImpl) AopContext.currentProxy()).save(deviceInfo);
        //step2 保存Emqx 鉴权信息
        EmqxAuth emqxAuth = new EmqxAuth();
        BeanUtils.copyProperties(dto.getEmqxAuth(), emqxAuth);
        emqxAuth.setDeviceCode(dto.getDeviceCode());
        emqxAuthService.save(emqxAuth);

        //step3 初始化设备指标阈值
        deviceThresholdService.initDeviceThreshold(deviceInfo.getDeviceCode());
        //step4 保存设备-客户-用户信息
        if (CollectionUtils.isEmpty(dto.getUserIdList())) {
            return 1;
        }

        List<DeviceUserRel> deviceUserRels = dto.getUserIdList().stream().map(userId -> {
            DeviceUserRel deviceUserRel = new DeviceUserRel();
            deviceUserRel.setDeviceCode(deviceInfo.getDeviceCode());
            deviceUserRel.setCustomerId(deviceInfo.getCustomerId());
            deviceUserRel.setUserId(userId);
            return deviceUserRel;
        }).toList();
        deviceUserRelService.saveBatch(deviceUserRels);
        return 1;

    }

    /**
     * 校验参数
     * @param dto
     */
    private void validModelCode(CreateDeviceInfoDto dto) {
        LambdaQueryWrapper<DeviceInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(DeviceInfo::getDeviceCode, dto.getDeviceCode());
        List<DeviceInfo> resultList = this.list(queryWrapper);
        if (!resultList.isEmpty()) {
            throw new ServiceException("设备编码已存在");
        }
    }

    /**
     * 修改设备信息
     *
     * @param deviceInfo 设备信息
     * @return 结果
     */
    @Override
    public int updateDeviceInfo(DeviceInfo deviceInfo) {
        return updateById(deviceInfo) ? 1 : 0;
    }

    /**
     * 批量删除设备信息
     *
     * @param ids 需要删除的设备信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceInfoByIds(String[] ids) {
        return removeByIds(Arrays.asList(ids)) ? 1 : 0;
    }

    /**
     * 删除设备信息信息
     *
     * @param id 设备信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceInfoById(String id) {
        return removeById(id) ? 1 : 0;
    }

    @Override
    public OverViewDto overview() {
        return deviceModelMapper.overview();
    }
}