package com.ruoyi.web.service.impl;

import java.util.Arrays;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.web.mapper.DeviceThresholdMapper;
import com.ruoyi.web.domain.DeviceThreshold;
import com.ruoyi.web.service.IDeviceThresholdService;
import lombok.RequiredArgsConstructor;

/**
 * 设备指标阈值信息Service业务层处理
 *
 * @author cx
 * @date 2025-04-05
 */
@Service
@RequiredArgsConstructor
public class DeviceThresholdServiceImpl extends ServiceImpl<DeviceThresholdMapper, DeviceThreshold> implements IDeviceThresholdService {
    private final DeviceThresholdMapper deviceThresholdMapper;

    /**
     * 查询设备指标阈值信息
     *
     * @param deviceCode 设备编码
     * @return 设备指标阈值信息
     */
    @Override
    public DeviceThreshold selectDeviceThresholdById(String deviceCode) {
        LambdaQueryWrapper<DeviceThreshold> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(DeviceThreshold::getDeviceCode, deviceCode);
        return getOne(queryWrapper);
    }

    /**
     * 查询设备指标阈值信息列表
     *
     * @param deviceThreshold 设备指标阈值信息
     * @return 设备指标阈值信息
     */
    @Override
    public List<DeviceThreshold> selectDeviceThresholdList(DeviceThreshold deviceThreshold) {
        LambdaQueryWrapper<DeviceThreshold> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(deviceThreshold.getDeviceCode() != null, DeviceThreshold::getDeviceCode, deviceThreshold.getDeviceCode());
        wrapper.eq(deviceThreshold.getOutl() != null, DeviceThreshold::getOutl, deviceThreshold.getOutl());
        wrapper.eq(deviceThreshold.getWtl() != null, DeviceThreshold::getWtl, deviceThreshold.getWtl());
        wrapper.eq(deviceThreshold.getAtl() != null, DeviceThreshold::getAtl, deviceThreshold.getAtl());
        wrapper.eq(deviceThreshold.getBtl() != null, DeviceThreshold::getBtl, deviceThreshold.getBtl());
        wrapper.eq(deviceThreshold.getOwst() != null, DeviceThreshold::getOwst, deviceThreshold.getOwst());
        wrapper.eq(deviceThreshold.getWfl() != null, DeviceThreshold::getWfl, deviceThreshold.getWfl());
        wrapper.eq(deviceThreshold.getSas() != null, DeviceThreshold::getSas, deviceThreshold.getSas());
        wrapper.eq(deviceThreshold.getCti() != null, DeviceThreshold::getCti, deviceThreshold.getCti());
        wrapper.eq(deviceThreshold.getRpssv1() != null, DeviceThreshold::getRpssv1, deviceThreshold.getRpssv1());
        wrapper.eq(deviceThreshold.getRpssc1() != null, DeviceThreshold::getRpssc1, deviceThreshold.getRpssc1());
        wrapper.eq(deviceThreshold.getFsc1() != null, DeviceThreshold::getFsc1, deviceThreshold.getFsc1());
        wrapper.eq(deviceThreshold.getFpsc1() != null, DeviceThreshold::getFpsc1, deviceThreshold.getFpsc1());
        wrapper.eq(deviceThreshold.getRpssv2() != null, DeviceThreshold::getRpssv2, deviceThreshold.getRpssv2());
        wrapper.eq(deviceThreshold.getRpssc2() != null, DeviceThreshold::getRpssc2, deviceThreshold.getRpssc2());
        wrapper.eq(deviceThreshold.getFsc2() != null, DeviceThreshold::getFsc2, deviceThreshold.getFsc2());
        wrapper.eq(deviceThreshold.getFpsc2() != null, DeviceThreshold::getFpsc2, deviceThreshold.getFpsc2());
        return list(wrapper);
    }

    /**
     * 新增设备指标阈值信息
     *
     * @param deviceThreshold 设备指标阈值信息
     * @return 结果
     */
    @Override
    public int insertDeviceThreshold(DeviceThreshold deviceThreshold) {
        return save(deviceThreshold) ? 1 : 0;
    }

    /**
     * 修改设备指标阈值信息
     *
     * @param deviceThreshold 设备指标阈值信息
     * @return 结果
     */
    @Override
    public int updateDeviceThreshold(DeviceThreshold deviceThreshold) {
        return updateById(deviceThreshold) ? 1 : 0;
    }

    /**
     * 批量删除设备指标阈值信息
     *
     * @param ids 需要删除的设备指标阈值信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceThresholdByIds(String[] ids) {
        return removeByIds(Arrays.asList(ids)) ? 1 : 0;
    }

    /**
     * 删除设备指标阈值信息信息
     *
     * @param id 设备指标阈值信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceThresholdById(String id) {
        return removeById(id) ? 1 : 0;
    }

    @Override
    public void initDeviceThreshold(String deviceCode) {

        DeviceThreshold sourceData = deviceThresholdMapper.selectById(1);
        sourceData.setId(null);
        sourceData.setDeviceCode(deviceCode);
        deviceThresholdMapper.insert(sourceData);
    }
}