package com.ruoyi.web.service.impl;

import java.util.Arrays;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.web.mapper.DeviceUserRelMapper;
import com.ruoyi.web.domain.DeviceUserRel;
import com.ruoyi.web.service.IDeviceUserRelService;
import lombok.RequiredArgsConstructor;

/**
 * 设备用户关联信息Service业务层处理
 *
 * @author cx
 * @date 2025-04-05
 */
@Service
@RequiredArgsConstructor
public class DeviceUserRelServiceImpl extends ServiceImpl<DeviceUserRelMapper, DeviceUserRel> implements IDeviceUserRelService
{
    private final DeviceUserRelMapper deviceUserRelMapper;

    /**
     * 查询设备用户关联信息
     *
     * @param id 设备用户关联信息主键
     * @return 设备用户关联信息
     */
    @Override
    public DeviceUserRel selectDeviceUserRelById(String id)
    {
        return getById(id);
    }

    /**
     * 查询设备用户关联信息列表
     *
     * @param deviceUserRel 设备用户关联信息
     * @return 设备用户关联信息
     */
    @Override
    public List<DeviceUserRel> selectDeviceUserRelList(DeviceUserRel deviceUserRel)
    {
        LambdaQueryWrapper<DeviceUserRel> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(deviceUserRel.getDeviceCode() != null, DeviceUserRel::getDeviceCode, deviceUserRel.getDeviceCode());
        wrapper.eq(deviceUserRel.getUserId() != null, DeviceUserRel::getUserId, deviceUserRel.getUserId());
        return list(wrapper);
    }

    /**
     * 新增设备用户关联信息
     *
     * @param deviceUserRel 设备用户关联信息
     * @return 结果
     */
    @Override
    public int insertDeviceUserRel(DeviceUserRel deviceUserRel)
    {
        return save(deviceUserRel) ? 1 : 0;
    }

    /**
     * 修改设备用户关联信息
     *
     * @param deviceUserRel 设备用户关联信息
     * @return 结果
     */
    @Override
    public int updateDeviceUserRel(DeviceUserRel deviceUserRel)
    {
        return updateById(deviceUserRel) ? 1 : 0;
    }

    /**
     * 批量删除设备用户关联信息
     *
     * @param ids 需要删除的设备用户关联信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceUserRelByIds(String[] ids)
    {
        return removeByIds(Arrays.asList(ids)) ? 1 : 0;
    }

    /**
     * 删除设备用户关联信息信息
     *
     * @param id 设备用户关联信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceUserRelById(String id)
    {
        return removeById(id) ? 1 : 0;
    }
}