package com.ruoyi.web.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.web.domain.EmqxAuth;
import com.ruoyi.web.mapper.EmqxAuthMapper;
import com.ruoyi.web.service.IEmqxAuthService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;

/**
 * 设备-EMQX鉴权信息Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-08
 */
@Service
@RequiredArgsConstructor
public class EmqxAuthServiceImpl extends ServiceImpl<EmqxAuthMapper, EmqxAuth> implements IEmqxAuthService {
    private final EmqxAuthMapper emqxAuthMapper;

    /**
     * 查询设备-EMQX鉴权信息
     *
     * @param id 设备-EMQX鉴权信息主键
     * @return 设备-EMQX鉴权信息
     */
    @Override
    public EmqxAuth selectEmqxAuthById(String id) {
        return getById(id);
    }

    /**
     * 查询设备-EMQX鉴权信息列表
     *
     * @param emqxAuth 设备-EMQX鉴权信息
     * @return 设备-EMQX鉴权信息
     */
    @Override
    public List<EmqxAuth> selectEmqxAuthList(EmqxAuth emqxAuth) {
        LambdaQueryWrapper<EmqxAuth> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(emqxAuth.getLocalUserName() != null, EmqxAuth::getLocalUserName, emqxAuth.getLocalUserName());
        wrapper.eq(emqxAuth.getLocalPass() != null, EmqxAuth::getLocalPass, emqxAuth.getLocalPass());
        wrapper.like(emqxAuth.getCloudUserName() != null, EmqxAuth::getCloudUserName, emqxAuth.getCloudUserName());
        wrapper.eq(emqxAuth.getCloudPass() != null, EmqxAuth::getCloudPass, emqxAuth.getCloudPass());
        return list(wrapper);
    }

    /**
     * 新增设备-EMQX鉴权信息
     *
     * @param emqxAuth 设备-EMQX鉴权信息
     * @return 结果
     */
    @Override
    public int insertEmqxAuth(EmqxAuth emqxAuth) {
        return save(emqxAuth) ? 1 : 0;
    }

    /**
     * 修改设备-EMQX鉴权信息
     *
     * @param emqxAuth 设备-EMQX鉴权信息
     * @return 结果
     */
    @Override
    public int updateEmqxAuth(EmqxAuth emqxAuth) {
        return updateById(emqxAuth) ? 1 : 0;
    }

    /**
     * 批量删除设备-EMQX鉴权信息
     *
     * @param ids 需要删除的设备-EMQX鉴权信息主键
     * @return 结果
     */
    @Override
    public int deleteEmqxAuthByIds(String[] ids) {
        return removeByIds(Arrays.asList(ids)) ? 1 : 0;
    }

    /**
     * 删除设备-EMQX鉴权信息信息
     *
     * @param id 设备-EMQX鉴权信息主键
     * @return 结果
     */
    @Override
    public int deleteEmqxAuthById(String id) {
        return removeById(id) ? 1 : 0;
    }
}