package com.ruoyi.web.service.impl;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.web.mapper.MaintenanceRecordMapper;
import com.ruoyi.web.domain.MaintenanceRecord;
import com.ruoyi.web.service.IMaintenanceRecordService;
import lombok.RequiredArgsConstructor;

/**
 * 设备维保记录Service业务层处理
 *
 * @author cx
 * @date 2025-04-05
 */
@Service
@RequiredArgsConstructor
public class MaintenanceRecordServiceImpl extends ServiceImpl<MaintenanceRecordMapper, MaintenanceRecord> implements IMaintenanceRecordService
{
    private final MaintenanceRecordMapper maintenanceRecordMapper;

    /**
     * 查询设备维保记录
     *
     * @param id 设备维保记录主键
     * @return 设备维保记录
     */
    @Override
    public MaintenanceRecord selectMaintenanceRecordById(String id)
    {
        return getById(id);
    }

    /**
     * 查询设备维保记录列表
     *
     * @param maintenanceRecord 设备维保记录
     * @return 设备维保记录
     */
    @Override
    public List<MaintenanceRecord> selectMaintenanceRecordList(MaintenanceRecord maintenanceRecord)
    {
        //todo 当前用户，所能查看的设备，需要用设备编码做数据权限
        Long userId = SecurityUtils.getUserId();
        LambdaQueryWrapper<MaintenanceRecord> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(maintenanceRecord.getDeviceName() != null, MaintenanceRecord::getDeviceName, maintenanceRecord.getDeviceName());
        wrapper.eq(maintenanceRecord.getDeviceModel() != null, MaintenanceRecord::getDeviceModel, maintenanceRecord.getDeviceModel());
        wrapper.eq(maintenanceRecord.getDeviceCode() != null, MaintenanceRecord::getDeviceCode, maintenanceRecord.getDeviceCode());
        wrapper.like(maintenanceRecord.getCustomerName() != null, MaintenanceRecord::getCustomerName, maintenanceRecord.getCustomerName());
        wrapper.eq(maintenanceRecord.getMaintenanceType() != null, MaintenanceRecord::getMaintenanceType, maintenanceRecord.getMaintenanceType());
        wrapper.eq(maintenanceRecord.getMaintenanceUser() != null, MaintenanceRecord::getMaintenanceUser, maintenanceRecord.getMaintenanceUser());
        wrapper.eq(maintenanceRecord.getMaintenanceDate() != null, MaintenanceRecord::getMaintenanceDate, maintenanceRecord.getMaintenanceDate());
        return list(wrapper);
    }

    /**
     * 新增设备维保记录
     *
     * @param maintenanceRecord 设备维保记录
     * @return 结果
     */
    @Override
    public int insertMaintenanceRecord(MaintenanceRecord maintenanceRecord)
    {
        maintenanceRecord.setCreateTime(new Date());
        maintenanceRecord.setCreateBy(SecurityUtils.getUsername());
        return save(maintenanceRecord) ? 1 : 0;
    }

    /**
     * 修改设备维保记录
     *
     * @param maintenanceRecord 设备维保记录
     * @return 结果
     */
    @Override
    public int updateMaintenanceRecord(MaintenanceRecord maintenanceRecord)
    {
        return updateById(maintenanceRecord) ? 1 : 0;
    }

    /**
     * 批量删除设备维保记录
     *
     * @param ids 需要删除的设备维保记录主键
     * @return 结果
     */
    @Override
    public int deleteMaintenanceRecordByIds(String[] ids)
    {
        return removeByIds(Arrays.asList(ids)) ? 1 : 0;
    }

    /**
     * 删除设备维保记录信息
     *
     * @param id 设备维保记录主键
     * @return 结果
     */
    @Override
    public int deleteMaintenanceRecordById(String id)
    {
        return removeById(id) ? 1 : 0;
    }
}